@@ -43,17 +43,19 @@ def clone(cnvrg, logger, name, override, cache_link, commit, threads, query):
 
 
 @dataset_group.command()
-@click.option('-n', '--name', prompt=messages.DATASET_PROMPT_NAME, help=messages.DATASET_HELP_CLONE)
+@click.option('-n', '--name', prompt=messages.DATASET_PROMPT_NAME, help=messages.DATASET_HELP_NAME)
 @click.option('-f', '--files', prompt=messages.DATASET_PUT_PROMPT_FILES, help=messages.DATASET_PUT_HELP_FILES)
-@click.option('-g', '--git-diff', is_flag=True, help=messages.DATA_UPLOAD_HELP_GIT_DIFF)
+@click.option('-fc', '--force', is_flag=True, help=messages.DATA_UPLOAD_HELP_FORCE)
+@click.option('-or', '--override', is_flag=True, help=messages.DATA_UPLOAD_HELP_OVERRIDE)
+@click.option('-gd', '--git-diff', is_flag=True, help=messages.DATA_UPLOAD_HELP_GIT_DIFF)
 @prepare_command()
-def put(cnvrg, logger, name, files, git_diff):
+def put(cnvrg, logger, name, files, force, override, git_diff):
     """
     Uploads the given files to the given dataset
     """
     file_paths = files.split(",")
     dataset = cnvrg.datasets.get(name)
-    dataset.put_files(paths=file_paths, progress_bar_enabled=True, git_diff=git_diff)
+    dataset.put_files(paths=file_paths, progress_bar_enabled=True, git_diff=git_diff, force=force, override=override)
     logger.log_and_echo(messages.DATA_UPLOAD_SUCCESS)
 
 
