@@ -360,3 +360,14 @@ class Context:
             else:
                 # Don't suppress unexpected exceptions
                 raise e
+
+    def get_env_variables(self):
+        """
+        Attempts to find credentials in environment variables
+        @return: token, domain, user
+        """
+        # Credential variables
+        token = self.token
+        domain = self.domain
+        user = self.user
+        return token, domain, user
