@@ -8,7 +8,7 @@ from cnvrgv2.utils.url_utils import urljoin
 
 class FileDownloader(RemoteFilesHandler):
     def __init__(self, data_owner, use_cached=False, num_workers=40, queue_size=5000, chunk_size=1000,
-                 force=False, progress_bar_enabled=False):
+                 force=False, progress_bar_enabled=False, query_slug=None):
         """
         Multithreaded file downloader - download files from server
         @param data_owner: Cnvrg dataset / project object
@@ -21,6 +21,8 @@ class FileDownloader(RemoteFilesHandler):
         self.commits_url = urljoin(data_owner._route, "commits", data_owner.last_commit,
                                    "files") + "?" + "page[after]={}&page[size]={}&sort=id&mode={}"
 
+        self.query_slug = query_slug
+
         super().__init__(
             data_owner,
             num_workers=num_workers,
@@ -31,8 +33,12 @@ class FileDownloader(RemoteFilesHandler):
             progress_bar_enabled=progress_bar_enabled
         )
 
+        total_files_query_url = self.commits_url.format('', 0, "files")
+        if query_slug:
+            total_files_query_url += "&query_slug={}".format(query_slug)
+
         total_files = data_owner._proxy.call_api(
-            route=self.commits_url.format('', 0, "files"),
+            route=total_files_query_url,
             http_method=HTTP.GET
         ).meta["total"]
 
@@ -60,7 +66,7 @@ class FileDownloader(RemoteFilesHandler):
                     }
                 ],
             }),
-            "query_slug": self.data_owner.query,
+            "query_slug": self.query_slug,
             "cache_link": self.use_cached
         }
 
