@@ -23,16 +23,11 @@ from cnvrgv2.modules.file import File
 from cnvrgv2.modules.folder import Folder
 from cnvrgv2.proxy import HTTP
 from cnvrgv2.utils.api_list_generator import api_list_generator
-from cnvrgv2.utils.path_generators import metadata_generator
 from cnvrgv2.utils.converters import convert_bytes
 from cnvrgv2.utils.filter_utils import list_to_multiple_conditions, Operators
-from cnvrgv2.utils.storage_utils import (
-    cnvrgignore_exists,
-    create_cnvrgignore,
-    build_cnvrgignore_spec,
-    create_dir_if_not_exists,
-    get_files_and_dirs_recursive
-)
+from cnvrgv2.utils.path_generators import metadata_generator
+from cnvrgv2.utils.storage_utils import (build_cnvrgignore_spec, cnvrgignore_exists, create_cnvrgignore,
+                                         create_dir_if_not_exists, get_files_and_dirs_recursive)
 from cnvrgv2.utils.url_utils import urljoin
 
 
@@ -363,8 +358,15 @@ class DataOwner(DynamicAttributes):
             payload=data
         ).meta
 
-    def clone(self, progress_bar_enabled=False, override=False, commit=None, use_cached=False, threads=40,
-              query_slug=None):
+    def clone(
+        self,
+        progress_bar_enabled=False,
+        override=False,
+        commit=None,
+        use_cached=False,
+        threads=40,
+        query_slug=None
+    ):
         """
         Clones the remote project / dataset
         @param progress_bar_enabled: Boolean indicating whenever or not to print a progress bar. In use of the cli
@@ -425,8 +427,15 @@ class DataOwner(DynamicAttributes):
         if not cnvrgignore_exists(self.slug):
             create_cnvrgignore(self.slug)
 
-    def upload(self, sync=False, job_slug=None, progress_bar_enabled=False, git_diff=False, message="",
-               output_dir=None):
+    def upload(
+        self,
+        sync=False,
+        job_slug=None,
+        progress_bar_enabled=False,
+        git_diff=False,
+        message="",
+        output_dir=None
+    ):
         """
         Uploads files to remote project / dataset
         @param sync: Boolean gives info if the put files comes from sync or not
@@ -597,15 +606,15 @@ class DataOwner(DynamicAttributes):
                     continue
 
                 if df.endswith('.deleted') or df.endswith('.deleted/'):
-                    original_file = re.sub(DataOwner.TMP_FOLDER_NAME, self.working_dir, df)
-                    original_file = re.sub(".deleted", "", original_file)
-                    if(os.path.isfile(original_file)):
+                    original_file = re.sub(re.escape(DataOwner.TMP_FOLDER_NAME), self.working_dir, df)
+                    original_file = re.sub(r"\.deleted", "", original_file)
+                    if os.path.isfile(original_file):
                         os.remove(original_file)
-                    elif(os.path.isdir(original_file)):
+                    elif os.path.isdir(original_file):
                         shutil.rmtree(original_file)
                     continue
 
-                new_path = re.sub(DataOwner.TMP_FOLDER_NAME, self.working_dir, df)
+                new_path = re.sub(re.escape(DataOwner.TMP_FOLDER_NAME), self.working_dir, df)
                 create_dir_if_not_exists(new_path)
 
                 # Prevents moving folders with content. Generally, creation of folders is done when dealing with files
@@ -619,7 +628,7 @@ class DataOwner(DynamicAttributes):
                 shutil.rmtree(tmp_folder)
 
     def _get_git_diff_files(self):
-        return list(filter(None, self.get_git_diff()))   # Clean from falsy values
+        return list(filter(None, self.get_git_diff()))  # Clean from falsy values
 
     def _list(self, mode, commit_sha1=None, query=None, query_raw=None, sort="-id"):
 
