@@ -1,7 +1,8 @@
 from cnvrgv2.proxy import Proxy, HTTP
 from cnvrgv2.modules.users.user import User
 from cnvrgv2.utils.json_api_format import JAF
-from cnvrgv2.errors import CnvrgArgumentsError
+from cnvrgv2.errors import CnvrgArgumentsError, CnvrgHttpError, CnvrgLoginError
+from json.decoder import JSONDecodeError
 from cnvrgv2.config import routes, error_messages
 from cnvrgv2.config.error_messages import FAULTY_VALUE
 from cnvrgv2.utils.validators import validate_url, validate_email, validate_username
@@ -26,24 +27,27 @@ class UsersClient:
         @return: token, first user organization (if exists)
         """
 
-        # If authentication fails, the proxy will throw unauthorized error
-        response = self._proxy.call_api(
-            route=routes.USER_LOGIN,
-            http_method=HTTP.POST,
-            payload={
-                "username": user,
-                "password": password
-            }
-        )
+        try:
+            # If authentication fails, the proxy will throw unauthorized error
+            response = self._proxy.call_api(
+                route=routes.USER_LOGIN,
+                http_method=HTTP.POST,
+                payload={
+                   "username": user,
+                   "password": password
+                }
+            )
 
-        token = response.meta.get("jwt")
-        organization = response.meta.get("organization", None)
+            token = response.meta.get("jwt")
+            organization = response.meta.get("organization", None)
 
         # update token and proxy for further usage
-        self._token = token
-        self._proxy = Proxy(domain=self._domain, token=self._token)
+            self._token = token
+            self._proxy = Proxy(domain=self._domain, token=self._token)
 
-        return token, organization
+            return token, organization
+        except (CnvrgHttpError, JSONDecodeError):
+            raise CnvrgLoginError(error_messages.INVALID_CREDENTIALS) from None
 
     def register(self, username, email, password):
         """
